##############################################
#
# timeline
# Module | Visual, linear arrangements of objects of type Event.
#
# Daniel Bakas Amuchastegui
# September 3, 2019
# 
# Copyright © Semantyk 2020. All rights reserved.
#############################################

from .graph import Graph

class Timeline(Graph):
    pass